@@ -48,8 +48,11 @@ struct _GdictWindow
 {
   GtkApplicationWindow parent_instance;
   
+  GtkWidget *header_bar;
   GtkWidget *main_box;
   GtkWidget *entry;
+  GtkWidget *spinner;
+  GtkWidget *stack;
   
   /* sidebar widgets */
   GtkWidget *speller;
@@ -63,9 +66,6 @@ struct _GdictWindow
   GtkWidget *defbox;
   GtkWidget *defbox_frame;
 
-  GtkWidget *status;
-  GtkWidget *progress;
-  
   GtkEntryCompletion *completion;
   GtkListStore *completion_model;
   
@@ -104,7 +104,6 @@ struct _GdictWindow
 
   guint is_maximized      : 1;
   guint sidebar_visible   : 1;
-  guint statusbar_visible : 1;
   guint in_construction   : 1;
   
   gulong window_id;
@@ -120,6 +119,7 @@ struct _GdictWindowClass
 
 GType      gdict_window_get_type (void) G_GNUC_CONST;
 GtkWidget *gdict_window_new      (GdictWindowAction  action,
+                                  GtkApplication    *app,
 				  GdictSourceLoader *loader,
 				  const gchar       *source_name,
                                   const gchar       *database_name,
